Atilla
======

Atilla (the API Utilities Library) contains a number of useful functions that are common between flask projects for
HTTP API applications. This includes types, validators, functions for creating applications,
etc. This library will make setting up new projects a lot faster.

.. image:: https://api.travis-ci.org/paylogic/atilla.png
   :target: https://travis-ci.org/paylogic/atilla

.. image:: https://pypip.in/v/atilla/badge.png
   :target: https://crate.io/packages/atilla/

.. image:: https://coveralls.io/repos/paylogic/atilla/badge.png?branch=master
   :target: https://coveralls.io/r/paylogic/atilla

.. image:: https://readthedocs.org/projects/atilla/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://readthedocs.org/projects/atilla/


Installation
------------

.. code-block:: shell

    pip install atilla


Documentation
-------------

Detailed python API you can find in the `documentation <http://atilla.readthedocs.org>`_.


Contact
-------

If you have questions, bug reports, suggestions, etc. please create an issue on
the `GitHub project page <http://github.com/paylogic/atilla>`_.


License
-------

This software is licensed under the `MIT license <http://en.wikipedia.org/wiki/MIT_License>`_

See `License file <https://github.com/paylogic/atilla/blob/master/LICENSE.txt>`_


© 2015 Paylogic International and others.
